@@ -9,22 +9,49 @@ from django.contrib import auth
 from django.contrib.auth.decorators import login_required
 import json
 import sys
-sys.path.append('..')
-sys.path.append('empty_my_fridge/model')
-sys.path.append('empty_my_fridge/empty_my_fridge/model')
+#sys.path.append('..')
+#sys.path.append('empty_my_fridge/model')
+#sys.path.append('empty_my_fridge/empty_my_fridge/model')
 import time
-from category import Category
-from route import ActivityPage
-from message import Message
-from recipes import Recipes
-from user import User
-import config
+#from category import Category
+#from route import ActivityPage
+#from message import Message
+#from recipes import Recipes
+#from user import User
+
+try:
+    from empty_my_fridge.model.user import User
+except ModuleNotFoundError:
+    from empty_my_fridge.empty_my_fridge.model.user import User
+
+try:
+    from empty_my_fridge.empty_my_fridge.model.recipes import Recipes
+except ModuleNotFoundError:
+    from empty_my_fridge.model.recipes import Recipes
+
+try:
+    from empty_my_fridge.model.category import Category
+except ModuleNotFoundError:
+    from empty_my_fridge.empty_my_fridge.model.category import Category
+
+try:
+    from empty_my_fridge.empty_my_fridge.model.message import Message
+except ModuleNotFoundError:
+    from empty_my_fridge.model.message import Message
+
+try:
+    from empty_my_fridge.model.route import ActivityPage
+except ModuleNotFoundError:
+    from empty_my_fridge.empty_my_fridge.model.route import ActivityPage
+
+try:
+    from config import myConfig
+except ModuleNotFoundError:
+    from empty_my_fridge.config import myConfig
+
 from . import allrecipes
 
-
-
-
-firebase = pyrebase.initialize_app(config.myConfig())
+firebase = pyrebase.initialize_app(myConfig())
 
 auth_fb = firebase.auth()
 fb_storage = firebase.storage()
